==> libsbml_5.6.0.orig.tar.gz: libsbml-5.6.0/src/sbml/conversion/test/TestRunner.c <==
/**
 * \file    TestRunner.c
 * \brief   Runs all unit tests in the math module
 * \author  Ben Bornstein
 * 
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2009-2012 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
 *  
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *  
 * Copyright (C) 2002-2005 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ---------------------------------------------------------------------- -->*/

#include <check.h>
#include <stdlib.h>
#include <string.h>

#include <sbml/util/memory.h>
#include <sbml/common/extern.h>


/**
 * Test suite creation function prototypes.
 *
 * These functions are needed only for calls in main() below.  Therefore a
 * separate header file is not necessary and only adds a maintenance burden
 * to keep the two files synchronized.
 */
#if defined(__cplusplus)
LIBSBML_CPP_NAMESPACE_USE
CK_CPPSTART
#endif

Suite *create_suite_TestConversionOption      (void);
Suite *create_suite_TestConversionProperties  (void);
Suite *create_suite_TestSBMLConverterRegistry (void);
Suite *create_suite_TestUnitsConverter (void);
Suite *create_suite_TestUnitsConverter2 (void);
Suite *create_suite_TestSBMLRuleConverter(void);
Suite *create_suite_TestUnitsConverterL2 (void);


/**
 * Global.
 *
 * Declared extern in TestReadFromFileN suites.
 */
char *TestDataDirectory;


/**
 * Sets TestDataDirectory for the the TestReadFromFileN suites.
 *
 * For Automake's distcheck target to work properly, TestDataDirectory must
 * begin with the value of the environment variable SRCDIR.
 */
void
setTestDataDirectory (void)
{
  char *srcdir = getenv("srcdir");
  int  length  = (srcdir == NULL) ? 0 : strlen(srcdir);


  /**
   * strlen("/test-data/") = 11 + 1 (for NULL) = 12
   */
  TestDataDirectory = (char *) safe_calloc( length + 12, sizeof(char) );

  if (srcdir != NULL)
  {
    strcpy(TestDataDirectory, srcdir);
    strcat(TestDataDirectory, "/");
  }

  strcat(TestDataDirectory, "test-data/");
}


int
main (void) 
{ 
  int num_failed;

  setTestDataDirectory();

  SRunner *runner = srunner_create( create_suite_TestConversionOption() );
  srunner_add_suite( runner, create_suite_TestSBMLRuleConverter      () );
  srunner_add_suite( runner, create_suite_TestConversionProperties   () );
  srunner_add_suite( runner, create_suite_TestSBMLConverterRegistry  () );
  srunner_add_suite( runner, create_suite_TestUnitsConverter         () );
  srunner_add_suite( runner, create_suite_TestUnitsConverter2        () );
  srunner_add_suite( runner, create_suite_TestUnitsConverterL2       () );

  /* srunner_set_fork_status(runner, CK_NOFORK); */

  srunner_run_all(runner, CK_NORMAL);
  num_failed = srunner_ntests_failed(runner);

  srunner_free(runner);

  return num_failed;
}

#if defined(__cplusplus)
CK_CPPEND
#endif

==> libsbml-5.21.0.tar.gz: libsbml-5.21.0/src/sbml/conversion/test/TestRunner.c <==
/**
 * \file    TestRunner.c
 * \brief   Runs all unit tests in the math module
 * \author  Ben Bornstein
 * 
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2020 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. University of Heidelberg, Heidelberg, Germany
 *     3. University College London, London, UK
 *
 * Copyright (C) 2019 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2013-2018 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *  
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *  
 * Copyright (C) 2002-2005 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ---------------------------------------------------------------------- -->*/

#include <check.h>
#include <stdlib.h>
#include <string.h>

#include <sbml/util/memory.h>
#include <sbml/common/extern.h>

#ifdef LIBSBML_USE_VLD
  #include <vld.h>
#endif

/**
 * Test suite creation function prototypes.
 *
 * These functions are needed only for calls in main() below.  Therefore a
 * separate header file is not necessary and only adds a maintenance burden
 * to keep the two files synchronized.
 */
#if defined(__cplusplus)
LIBSBML_CPP_NAMESPACE_USE
CK_CPPSTART
#endif

Suite *create_suite_TestConversionOption      (void);
Suite *create_suite_TestConversionProperties  (void);
Suite *create_suite_TestSBMLConverterRegistry (void);
Suite *create_suite_TestUnitsConverter (void);
Suite *create_suite_TestUnitsConverter2 (void);
Suite *create_suite_TestSBMLRuleConverter(void);
Suite *create_suite_TestUnitsConverterL2 (void);
Suite *create_suite_TestInferUnitsConverter (void);
Suite *create_suite_TestStripPackageConverter (void);
Suite *create_suite_TestLevelVersionConverter(void);
Suite *create_suite_TestRateOfConverter(void);
Suite *create_suite_TestSBMLRateRuleConverter(void);

Suite* create_suite_TestExpressionAnalyser(void);
Suite* create_suite_TestSBMLRoundtripConverter(void);
Suite* create_suite_TestSBMLReactionConverter(void);

/**
 * Global.
 *
 * Declared extern in TestReadFromFileN suites.
 */
char *TestDataDirectory;


/**
 * Sets TestDataDirectory for the the TestReadFromFileN suites.
 *
 * For Automake's distcheck target to work properly, TestDataDirectory must
 * begin with the value of the environment variable SRCDIR.
 */
void
setTestDataDirectory (void)
{
  char *srcdir = getenv("srcdir");
  size_t  length  = (srcdir == NULL) ? 0 : strlen(srcdir);


  /**
   * strlen("/test-data/") = 11 + 1 (for NULL) = 12
   */
  TestDataDirectory = (char *) safe_calloc( length + 12, sizeof(char) );

  if (srcdir != NULL)
  {
    strcpy(TestDataDirectory, srcdir);
    strcat(TestDataDirectory, "/");
  }

  strcat(TestDataDirectory, "test-data/");
}


int
main (void) 
{ 
  int num_failed;

  setTestDataDirectory();
////SRunner* runner = srunner_create(create_suite_TestSBMLRateRuleConverter());
// // SRunner* runner = srunner_create(create_suite_TestSBMLReactionConverter());
// SRunner* runner = srunner_create(create_suite_TestSBMLRateRuleConverter());
//  srunner_add_suite(runner, create_suite_TestSBMLReactionConverter());
//  srunner_add_suite(runner, create_suite_TestSBMLRoundtripConverter());

  SRunner *runner = srunner_create( create_suite_TestConversionOption() );
  srunner_add_suite( runner, create_suite_TestSBMLRuleConverter      () );
  srunner_add_suite( runner, create_suite_TestConversionProperties   () );
  srunner_add_suite( runner, create_suite_TestSBMLConverterRegistry  () );
  srunner_add_suite( runner, create_suite_TestUnitsConverter         () );
  srunner_add_suite( runner, create_suite_TestUnitsConverter2        () );
  srunner_add_suite( runner, create_suite_TestUnitsConverterL2       () );
  srunner_add_suite( runner, create_suite_TestInferUnitsConverter    () );
  srunner_add_suite( runner, create_suite_TestStripPackageConverter  () );
  srunner_add_suite( runner, create_suite_TestLevelVersionConverter  () );
  srunner_add_suite( runner, create_suite_TestRateOfConverter        () );
  srunner_add_suite(runner, create_suite_TestExpressionAnalyser());
  srunner_add_suite( runner, create_suite_TestSBMLRateRuleConverter  () );
  srunner_add_suite( runner, create_suite_TestSBMLRoundtripConverter  () );
  srunner_add_suite( runner, create_suite_TestSBMLReactionConverter  () );

  /* srunner_set_fork_status(runner, CK_NOFORK); */

  srunner_run_all(runner, CK_NORMAL);
  num_failed = srunner_ntests_failed(runner);

  srunner_free(runner);

  safe_free(TestDataDirectory);

  return num_failed;
}

#if defined(__cplusplus)
CK_CPPEND
#endif
